export default {
    name: 'myRefreshList',
    props: {
      // 是否加载失败，加载失败后点击错误提示可以重新触发load事件，必须使用sync修饰符
      error: {
        type: Boolean,
        default: false
      },
      // 是否在初始化时立即执行滚动位置检查
      immediateCheck: {
        type: Boolean,
        default: false
      },
      // 提示内容
      errorText: {
        type: String,
        default: '好像出了点问题，再点下试试？'
      },
      finishedTest: {
        type: String,
        default: '没有更多了'
      },
      // 是否处于加载状态，加载过程中不触发load事件
      isLoading: {
        type: Boolean,
        default: false
      },
      // 是否已加载完成，加载完成后不再触发load事件
      isFinished: {
        type: Boolean,
        default: false
      },
      // 是否处于加载中状态
      isRefreshing: {
        type: Boolean,
        default: false
      }
    },
    data () {
      return {
        // 是否处于加载状态，加载过程中不触发load事件
        loading: this.isLoading,
        // 是否已加载完成，加载完成后不再触发load事件
        finished: this.isFinished,
        // 是否处于加载中状态
        refreshing: this.isRefreshing
      }
    },
    methods: {
      // 下拉刷新
      onRefresh () {
        this.$emit('on-refresh')
      },
      // 上拉加载
      onLoad () {
        this.$emit('on-load')
      }
    },
    watch: {
      // 是否处于加载状态，加载过程中不触发load事件
      isLoading (val) {
        this.loading = val
      },
      // 是否已加载完成，加载完成后不再触发load事件
      isRefreshing (val) {
        this.refreshing = val
      },
      // 是否处于加载中状态
      isFinished (val) {
        this.finished = val
      },
      // 是否处于加载中状态
      finished (val) {
        this.$emit('on-finished', val)
      },
      // 是否处于加载状态，加载过程中不触发load事件
      loading (val) {
        this.$emit('on-loading', val)
      },
      // 是否已加载完成，加载完成后不再触发load事件
      refreshing (val) {
        this.$emit('on-refreshing', val)
      }
    }
  }